package RPC::OGo::Account;
#
# $Id: Account.pm,v 1.2 2003/12/15 14:39:46 martin Exp $
#

$VERSION = "0.1";

use Carp;
use strict;

use base qw(RPC::OGo);
use RPC::OGo::Document::Account;

=head1 NAME RPC::OGo::Account - Access RPC::OGo account documents

=head1 SYNOPSIS

    use Ogo;
    use RPC::OGo::Account;

    my $Account = new RPC::OGo::Account( login     => 'martin',
                                         password  => 'secret',
                                         firstname => 'Martin',
                                         name      => 'Werthmoeller'
                                  );
    $Account->insert();


    my $Account = new RPC::OGo::Account();
    $Account->fetch('martin');
    print "Id: ",$Account->id,"\n";

=head1 METHODS

=head2 new([$login][,$name][,$firstname])

Creates a new RPC::OGo::Account object and returns it. The login, name
and firstname can be set with the parameters.

=cut
sub new {
    my $class = shift;
    my @param = @_;

    my $self = {};
    $self->{'login'}     = $param[0];
    $self->{'name'}      = $param[1];
    $self->{'firstname'} = $param[2];

    bless $self, $class;
    return $self;
}


=head2 passwordForLogin([$login])

Fetches the (crypted) password of the login $login or the current
account object and returns it.  This command can only be used by the
user 'root'.

=cut
sub passwordForLogin {
    my ($self,$attr) = @_;

    unless ($RPC::OGo->{'login'} eq 'root') {
        carp "Only user root can fetch passwords\n";
        return '';
    }
    my $login = $attr || $self->{'login'};
    carp "No login given\n" unless $login;
    return $self->_call("passwordForLogin",$login);
}


=head2 getByLogin($login)

Fetches the account document for the login $login. Returns this
account document.

=cut
sub getByLogin {
    my ($self,$attr) = @_;

    my $login = $attr || $self->{'login'};
    carp "No login given\n" unless $login;
    my $ret = $self->_call("getByLogin",$login);
    return RPC::OGo::Document->createObject($self,$ret);
}


=head2 deleteByLogin($login)

Deletes the account with the login $login. Returns the current
object.

=cut
sub deleteByLogin {
    my ($self,$attr) = @_;

    $self->_warn('login') unless $attr;
    my $ret = $self->_call('deleteByLogin',$attr);

    $self->{'error'} = 0; # no return value from XMLRPC call
    return $self;
}


=head2 getAllTemplateUserLogins()

Returns an array of all template user login names.

=cut
sub getAllTemplateUserLogins {
    my ($self) = @_;

    my $ret = $self->_call('getAllTemplateUserLogins');
    return @{$ret};
}


=head2 setPassword($id,$password)

Sets the password for for the login with the id $id. Returns a true
value if successful.

=cut
sub setPassword {
    my ($self,$id,$pass) = @_;

    my $salt = join '',
        ('.', '/', 0..9, 'A'..'Z', 'a'..'z')[rand 64, rand 64];
    my $cpass = crypt $pass,$salt;

    return $self->_call('setPassword',$id,$cpass,'true');
}





### EOP ###
1;
__END__

=head1 AUTHOR

Martin Werthmoeller <lt>mw@werthmoeller.de<gt>

=head1 SEE ALSO

L<perl>, L<RPC::OGo::Document>.

=cut
