package RPC::OGo::Appointment;
#
# $Id: Appointment.pm,v 1.1 2003/12/15 14:39:46 martin Exp $
#

$VERSION = "0.1";

use Text::Iconv;
use Carp;
use strict;

use base qw/RPC::OGo/;
use RPC::OGo::Document::Appointment;

=head1 NAME RPC::OGo::Appointment - Access RPC::OGo appointment documents

=head1 SYNOPSIS

    use RPC::Ogo;
    use RPC::OGo::Appointment;

    my $ogo = new RPC::OGo;

    my $Appointment = new RPC::OGo::Appointment();

    my @apmts = $Appointment->fetch($start,$end);

=head1 METHODS

=head2 new()

RPC::OGo::Appointment constructor. Returns an RPC::OGo::Appointment object.

=cut
sub new {
    my $class = shift;
    my $self = {};
    bless $self, $class;
    return $self;
}


=head2 fetch(<startDate>,<endDate>)

Returns an array of RPC::OGo::Document::Appointment objects

=cut
sub fetch {
    my ($self,$start,$end) = @_;
    my $ret = $self->_call('fetch',{qualifier => { 'startDate' => $start,
                                                   'endDate'   => $end,
                                                  },
                                   });
    my @objary;
    foreach (@{$ret}) {
        push @objary, RPC::OGo::Document::Appointment->new($_);
    }
    return @objary;
}


=head2 setParticipants($appointment,$pcpt1,[$pcpt2, ...])

Set the participants to $appointment appointment object. Returns the
new appointment document object with the added participants. The
$pcpt? attributes are person or team documents.

=cut
sub setParticipants {
    my ($self,$appt,@plist) = @_;
    my $ret = $self->_call('setParticipants',$appt,\@plist);

    return RPC::OGo::Document::Appointment->new($ret);
}


=head2 delete($appointmentDoc)

This method deletes the appointment document referenced by
$appointmentDoc. The appointment document must contain the 'id'
attribute. Returns the current RPC::OGo::Appointment object.

=cut
sub delete {
    my ($self,$appt) = @_;
    return undef unless $appt->{'id'};
    my $ret = $self->_call('delete',$appt);

    return $self;
}


=head2 fetchIds(<startDate>,<endDate>[,$strip])

Returns an array of Appointment ids. If $strip is a true value, the
plain id will returned instead of the URI form. The XMLRPC API accepts
both forms.

=cut
sub fetchIds {
    my ($self,$start,$end,$strip) = @_;
    my $ret = $self->_call('fetch',{qualifier => { 'startDate' => $start,
                                                   'endDate'   => $end,
                                                  },
                                   });

    if ($strip) {
        foreach my $id (@{$ret}) {
            # strip ids from string
            $id =~ s/^.+?([^\/]+)$/$1/;
        }
    }
    return @{$ret};
}


# =head2 insert([\%params])

# Inserts the current object into the OGo database. The optional hashref
# $params could set or overwrite some of the attributes of the current
# object. Returns assigned document returned from OGo.

# =cut
# sub insert {
#     my ($self,$params) = @_;
#     if (defined $params) {
#         foreach (keys %{$params}) {
#             $self->{$_} = $params->{$_};
#         }
#     }
#     my $ret = $self->_call('insert',$self);

#     return RPC::OGo::Document->createObject($self,$ret);
# }


### EOP ###
1;
__END__

=head1 AUTHOR

Martin Werthmoeller <lt>mw@werthmoeller.de<gt>

=head1 SEE ALSO

L<perl>, L<RPC::OGo::Document>.

=cut

