package RPC::OGo::Date;
#
# $Id: Date.pm,v 1.1 2003/12/15 14:39:46 martin Exp $
#

$VERSION = "0.1";

use POSIX qw(strftime);
use Carp;
use strict;

require Exporter;
require DynaLoader;

our @ISA = qw(Exporter DynaLoader);
our @EXPORT = qw(epoch2dateString dateString2epoch dateString2local
                 string2dateString);

=head1 NAME RPC::OGo::Date - Convert date and time statements

=head1 SYNOPSIS

    use RPC::OGo::Date;
    my $now = time();
    my $dateString = epoch2dateString($now);
    my $epoch      = dateString2epoch($dateString);
    my $string     = dateString2local($dateString);
    my $dateString = string2dateString($string)

=head1 DESCRIPTION

This module contains some helper functions for date conversion from
and to the date format used by XMLRPC.

=cut

=head2 epoch2dateString($epoch)

Returns time given by $epoch seconds in dateString (ISO8601) Format.

=cut
sub epoch2dateString {
    return strftime "%Y%m%dT%H:%M:%S",localtime(shift());
}

=head2 dateString2epoch($dateString)

Returns time given by the dateString (ISO8601) Format in seconds of
the epoch.

=cut
sub dateString2epoch {
    my $dateString = shift;

    my ($year,$mon,$day,$hour,$min,$sec) =
        $dateString =~ /(\d{4})(\d{2})(\d{2})T(\d{2}):(\d{2}):(\d{2})/;
    $year -= 1900; $mon  -= 1;

    return strftime "%s",$sec,$min,$hour,$day,$mon,$year;
}

=head2 dateString2local($dateString)

Returns time given by the dateString (ISO8601) Format as a clear text
string like " Mon 15 Dez 2003 11:26:57 CET" =cut

=cut
sub dateString2local {
    my $dateString = shift;

    my ($year,$mon,$day,$hour,$min,$sec) =
        $dateString =~ /(\d{4})(\d{2})(\d{2})T(\d{2}):(\d{2}):(\d{2})/;
    $year -= 1900; $mon  -= 1;

    return strftime "%c",$sec,$min,$hour,$day,$mon,$year;
}


=head2 string2dateString($string)

Returns time given by $string in dateString
(ISO8601) Format. The format of $string is: YYYY-MM-DD hh:mm.

=cut
sub string2dateString {
    my ($string) = @_;
    $string =~ s/-//g;
    $string =~ s/\s/T/;
    $string .= ":00";
    return $string;
}



### EOP ###
1;
__END__

=head1 AUTHOR

Martin Werthmoeller <lt>mw@werthmoeller.de<gt>

=head1 SEE ALSO

L<perl>, L<RPC::OGo>.

=cut
