package RPC::OGo::Document::Addresses;
#
# $Id: Addresses.pm,v 1.1 2003/12/15 14:39:46 martin Exp $
#

$VERSION = "0.1";

use Carp;
use strict;
use vars;

use base qw/RPC::OGo::Document/;

=head1 NAME

RPC::OGo::Document::Addresses - Addresses Subdocument class

=head1 SYNOPSIS

    use  RPC::OGo::Document::Addresses;

    my $address = new RPC::OGo::Document::Addresses($document);

    $city = $address->city;

=head1 DESCRIPTION

RPC::OGo::Document::Addresses handles the access to the addresses of a
person document for OpenGroupware XMLRPC calls.

=head1 METHODS

=head2 new($document)

Creates a new Addresses document from $document. The document is a
person or a enterprise document or class.

=cut
sub new {
    my ($class,$object) = @_;

    return undef unless $object;

    my $self = $object->addresses();
    bless $self, $class;
    return $self;
}


=head2 name1($type,[$newval])

Returns the name1 of the address type $type. Type should be one of
'location', 'mailing', 'private' on person documents, respective
'ship' or 'bill' on enterprise documents. If $newval is set, the
attribute will be set to value. Returns the value of the attribute.

=cut
sub name1 {
    my ($self,$type,$val) = @_;
    $self->{$type}->{'name1'} = $val if defined($val);
    return $self->{$type}->{'name1'};
}


=head2 street($type,[$newval])

Returns the street of the address type $type. Type should be one of
'location', 'mailing', 'private' on person documents, respective
'ship' or 'bill' on enterprise documents. If $newval is set, the
attribute will be set to value. Returns the value of the attribute.

=cut
sub street {
    my ($self,$type,$val) = @_;
    $self->{$type}->{'street'} = $val if defined($val);
    return $self->{$type}->{'street'};
}


=head2 city($type,[$newval])

Returns the city of the address type $type. Type should be one of
'location', 'mailing', 'private' on person documents, respective
'ship' or 'bill' on enterprise documents. If $newval is set, the
attribute will be set to value. Returns the value of the attribute.

=cut
sub city {
    my ($self,$type,$val) = @_;
    $self->{$type}->{'city'} = $val if defined($val);
    return $self->{$type}->{'city'};
}


=head2 zip($type,[$newval])

Returns the zip of the address type $type. Type should be one of
'location', 'mailing', 'private' on person documents, respective
'ship' or 'bill' on enterprise documents. If $newval is set, the
attribute will be set to value. Returns the value of the attribute.

=cut
sub zip {
    my ($self,$type,$val) = @_;
    $self->{$type}->{'zip'} = $val if defined($val);
    return $self->{$type}->{'zip'};
}


=head2 country($type,[$newval])

Returns the country of the address type $type. Type should be one of
'location', 'mailing', 'private' on person documents. If $newval is
set, the attribute will be set to value. Returns the value of the
attribute.

=cut
sub country {
    my ($self,$type,$val) = @_;
    $self->{$type}->{'country'} = $val if defined($val);
    return $self->{$type}->{'country'};
}


=head2 name2($type,[$newval])

Returns the name2 of the address type $type. Type should be one of
'location', 'mailing', 'private' on person documents. If $newval is
set, the attribute will be set to value. Returns the value of the
attribute.

=cut
sub name2 {
    my ($self,$type,$val) = @_;
    $self->{$type}->{'name2'} = $val if defined($val);
    return $self->{$type}->{'name2'};
}


=head2 name3($type,[$newval])

Returns the name3 of the address type $type. Type should be one of
'location', 'mailing', 'private' on person documents. If $newval is
set, the attribute will be set to value. Returns the value of the
attribute.

=cut
sub name3 {
    my ($self,$type,$val) = @_;
    $self->{$type}->{'name3'} = $val if defined($val);
    return $self->{$type}->{'name3'};
}


=head2 state($type,[$newval])

Returns the state of the address type $type. Type should be one of
'location', 'mailing', 'private' on person documents. If $newval is
set, the attribute will be set to value. Returns the value of the
attribute.

=cut
sub state {
    my ($self,$type,$val) = @_;
    $self->{$type}->{'state'} = $val if defined($val);
    return $self->{$type}->{'state'};
}


### EOP ###
1;
__END__

=head1 AUTHOR

Martin Werthmoeller <lt>mw@werthmoeller.de<gt>

=head1 SEE ALSO

L<perl>, L<RPC::OGo::Document>.

=cut
