package RPC::OGo::Document::Appointment;
#
# $Id: Appointment.pm,v 1.1 2003/12/15 14:39:46 martin Exp $
#

$VERSION = "0.1";

use Carp;
use strict;
use vars;

use base qw/RPC::OGo::Document/;

=head1 NAME

RPC::OGo::Document::Appointment - Appointment Document class

=head1 SYNOPSIS

my $doc = new RPC::OGo::Document::Appointment();

my $doc = new RPC::OGo::Document::Appointment($appmntDocument);


=head1 DESCRIPTION

RPC::OGo::Document::Appointment handles the access to the Appointment
document for OpenGroupware XMLRPC calls.

=head1 METHODS

=cut

=head2 new([$appointmentDocument])

Creates a new (empty) appointment document. If the parameter
$appointmentDocument is given, the object will be initialized with
this document. Returns the account object.

=cut
sub new {
    my ($class,$data) = @_;

    my $self;
    if ($data) {
        $self = $data;
        bless $self, $class;
    }
    else {
        $self = {};
        bless $self, $class;
        $self->_init();
    }
    return $self;
}


sub _init {
    my ($self) = shift;

    $self = { 'startDate'    => '',
              'endDate'      => '',
              'type'         => '',
              'cycleEndDate' => '',
              'location'     => '',
              'participants' => [], # list of person documents
            }
}


=head2 participants()

Returns a list of person objects who are the participants of this
apptointment.

=cut
sub participants {
    my ($self) = shift;

    require RPC::OGo::Document::Person;
    my @ret;
    foreach (@{$self->{'participants'}}) {
        push @ret, RPC::OGo::Document::Person->new($_);
    }
    return @ret;
}


### EOP ###
1;
__END__

=head1 AUTHOR

Martin Werthmoeller <lt>mw@werthmoeller.de<gt>

=head1 SEE ALSO

L<perl>, L<RPC::OGo::Document>.

=cut
