package RPC::OGo::Document::Enterprise;
#
# $Id: Enterprise.pm,v 1.2 2003/12/15 14:39:46 martin Exp $
#

$VERSION = "0.1";

use Carp;
use strict;
use vars;

use base qw/RPC::OGo::Document/;

=head1 NAME

RPC::OGo::Document::Enterprise - Enterprise Document class

=head1 SYNOPSIS

my $doc = new RPC::OGo::Document::Enterprise();

my $doc = new RPC::OGo::Document::Enterprise($enterpriseDocument);


=head1 DESCRIPTION

RPC::OGo::Document::Enterprise handles the access to the Enterprise
document for OpenGroupware XMLRPC calls.

=head1 METHODS

=cut

=head2 new([$enterpriseDocument])

Creates a new (empty) account document. If the parameter
$enterpriseDocument is given, the object will be initialized with this
document. Returns the account object.

=cut
sub new {
    my ($class,$data) = @_;

    my $self = {};
    if ($data) {
        $self = $data;
        bless $self, $class;
    }
    else {
        bless $self, $class;
        $self->_init();
    }

    return $self;
}


# initialize empty enterprise document
sub _init {
    my ($self) = shift;

    return $self = {
                    'extendedAttrs' => '',
                    'id'            => '',
                    'number'        => '',
                    'name'          => '',
                    'url'           => '',
                    'email'         => '',
                    'addresses'=> {
                        'ship'=> {
                                  'type'   => 'ship',
                                  'id'     => '',
                                  'name1'  => '',
                                  'street' => '',
                                  'city'   => '',
                                  'zip'    => '',
                                 },
                         'bill'=> {
                                   'type'   => 'bill',
                                   'id'     => '',
                                   'name1'  => '',
                                   'street' => '',
                                   'zip'    => '',
                                   'city'   => '',
                                  },
                     },
#                    'extendedKeys'=> ['email2', 'email3', 'job_title',
#                                      'other_title1', 'other_title2'],
#                    'phoneTypes'=> ['01_tel', '02_tel', '10_fax'],
                     'phones' => {
                                 '10_fax'=> {
                                             'type'        => '10_fax',
                                             'info'        => '',
                                             'number'      => ''
                                            },
                                 '01_tel'=> {
                                             'type'        => '01_tel',
                                             'info'        => '',
                                             'number'      => ''
                                            },
                                 '02_tel'=> {
                                             'type'        => '02_tel',
                                             'info'        => '',
                                             'number'      => ''
                                            },
                                },
                    'keywords'   => '',
                    'comment'    => '',
                   };
}


### EOP ###
1;
__END__

=head1 AUTHOR

Martin Werthmoeller <lt>mw@werthmoeller.de<gt>

=head1 SEE ALSO

L<perl>, L<RPC::OGo::Document>.

=cut
