package RPC::OGo::Document::Person;
#
# $Id: Person.pm,v 1.2 2003/12/15 14:39:46 martin Exp $
#

$VERSION = "0.1";

use Carp;
use strict;
use vars;

use base qw/RPC::OGo::Document/;

=head1 NAME

RPC::OGo::Document::Person - Person Document class

=head1 SYNOPSIS

my $doc = new RPC::OGo::Document::Person();

my $doc = new RPC::OGo::Document::Person($personDocument);


=head1 DESCRIPTION

RPC::OGo::Document::Person handles the access to the Person document for
OpenGroupware XMLRPC calls.

=head1 METHODS

=cut

=head2 new([$personDocument])

Creates a new (empty) person document. If the parameter
$personDocument is given, the object will be initialized with this
document. Returns the account object.

=cut
sub new {
    my ($class,$data) = @_;

    my $self;
    if ($data) {
        $self = $data;
        bless $self, $class;
    }
    else {
        $self = {};
        bless $self, $class;
        $self->_init();
    }
    return $self;
}

# nested attributes

=head2 email()

This method returns the first occurance of an email address at the
data structure.

=cut
sub email {
    my ($self) = @_;
    if (defined ($self->{'extendedAttrs'}->{'email1'})) {
        return $self->{'extendedAttrs'}->{'email1'};
    }
    elsif (defined ($self->{'extendedAttrs'}->{'email2'})) {
        return $self->{'extendedAttrs'}->{'email2'};
    }
    elsif (defined ($self->{'extendedAttrs'}->{'email3'})) {
        return $self->{'extendedAttrs'}->{'email3'};
    }
    return '';
}


=head2 emailN()

This method returns the value of emailN where N is one of 1-n defined
email addresses at the data structure.

=cut
sub email1 {
    my ($self) = @_;
    if (defined ($self->{'extendedAttrs'}->{'email1'})) {
        return $self->{'extendedAttrs'}->{'email1'};
    }
    else {
        return '';
    }
}

sub email2 {
    my ($self) = @_;
    if (defined ($self->{'extendedAttrs'}->{'email2'})) {
        return $self->{'extendedAttrs'}->{'email2'};
    }
    else {
        return '';
    }
}

sub email3 {
    my ($self) = @_;
    if (defined ($self->{'extendedAttrs'}->{'email3'})) {
        return $self->{'extendedAttrs'}->{'email3'};
    }
    else {
        return '';
    }
}

=head2 job_title(), other_titleN()

This method returns the value of the named title.

=cut
sub job_title {
    my ($self) = @_;
    if (defined ($self->{'extendedAttrs'}->{'job_title'})) {
        return $self->{'extendedAttrs'}->{'job_title'};
    }
    else {
        return '';
    }
}

sub other_title1 {
    my ($self) = @_;
    if (defined ($self->{'extendedAttrs'}->{'other_title1'})) {
        return $self->{'extendedAttrs'}->{'other_title1'};
    }
    else {
        return '';
    }
}

sub other_title2 {
    my ($self) = @_;
    if (defined ($self->{'extendedAttrs'}->{'other_title2'})) {
        return $self->{'extendedAttrs'}->{'other_title2'};
    }
    else {
        return '';
    }
}

=head2 cellphone()

This method returns the number of the cellphone.

=cut
sub cellphone {
    my ($self) = @_;
    if (defined ($self->{'phones'}->{'03_tel_funk'}->{'number'})) {
        return$ self->{'phones'}->{'03_tel_funk'}->{'number'};
    }
    else {
        return '';
    }
}


=head2 privatephone()

This method returns the private telephone number.

=cut
sub privatephone {
    my ($self) = @_;
    if (defined ($self->{'phones'}->{'05_tel_private'}->{'number'})) {
        return$ self->{'phones'}->{'05_tel_private'}->{'number'};
    }
    else {
        return '';
    }
}


=head2 privatefax()

This method returns the private fax number.

=cut
sub privatefax {
    my ($self) = @_;
    if (defined ($self->{'phones'}->{'15_fax_private'}->{'number'})) {
        return$ self->{'phones'}->{'15_fax_private'}->{'number'};
    }
    else {
        return '';
    }
}


# initialize empty person document
sub _init {
    my ($self) = shift;

    return $self = {
            addresses => {
                          location => {
                                       city    => '',
                                       country => '',
                                       name1   => '',
                                       name2   => '',
                                       name3   => '',
                                       state   => '',
                                       street  => '',
                                       type    => 'location',
                                       zip     => '',
                                       city    => '',
                                      },
                          mailing  => {
                                       city    => '',
                                       country => '',
                                       name1   => '',
                                       name2   => '',
                                       name3   => '',
                                       state   => '',
                                       street  => '',
                                       type    => 'mailing',
                                       zip     => '',
                                       city    => '',
                                      },
                          private   => {
                                       city    => '',
                                       country => '',
                                       name1   => '',
                                       name2   => '',
                                       name3   => '',
                                       state   => '',
                                       street  => '',
                                       type    => 'private',
                                       zip     => '',
                                       city    => '',
                                      },
                         },

             birthday      => '',
             comment       => '',
             contact       => { login => '', },
             degree        => '',
             extendedAttrs => {
                               email1       => '',
                               email2       => '',
                               job_title    => '',
                               other_title1 => '',
                               other_title2 => '',
                             },

             firstname     => '',
             gender        => '',
             isAccount     => '',
             isComplete    => '',
             isPrivate     => '',
             keywords      => '',
             login         => '',
             middlename    => '',
             name          => '',
             nickname      => '',
            #        phoneTypes => ['01_tel','03_tel_funk','10_fax'],
             phones        => {
                           '01_tel'      => { info   => '',
                                              number => '',
                                              type   => '01_tel', # hard c.
                                            },
                           '02_tel'      => { info   => '',
                                              number => '',
                                              type   => '02_tel',
                                            },
                           '03_tel_funk' => { info   => '',
                                              number => '',
                                              type   => '03_tel_funk',
                                            },
                           '05_tel_private' => {
                                              info   => '',
                                              number => '',
                                              type   => '05_tel_private',
                                            },
                           '10_fax'      => { info   => '',
                                              number => '',
                                              type   => '10_fax',
                                            },
                           '15_fax_private' => {
                                              info   => '',
                                              number => '',
                                              type   => '15_fax_private',
                                            },
                          },
             salutation => '',
             url        => '',
            };
}


### EOP ###
1;
__END__

=head1 AUTHOR

Martin Werthmoeller <lt>mw@werthmoeller.de<gt>

=head1 SEE ALSO

L<perl>, L<RPC::OGo::Document>.

=cut
