package RPC::OGo::Enterprise;
#
# $Id: Enterprise.pm,v 1.2 2003/12/15 14:39:46 martin Exp $
#

$VERSION = "0.1";

use Text::Iconv;
use Carp;
use strict;

use base qw/RPC::OGo/;
use RPC::OGo::Document::Enterprise;

=head1 NAME RPC::OGo::Enterprise - Access RPC::OGo enterprise documents

=head1 SYNOPSIS

    use RPC::Ogo;
    use RPC::OGo::Enterprise;

    my $ogo = new RPC::OGo;

    my $Enterprise = new RPC::OGo::Enterprise(%params);

    $Enterprise->insert;

=head2 new()

RPC::OGo::Enterprise constructor. Returns an RPC::OGo::Enterprise object.

=cut
sub new {
    my $this = shift;
    my $class = ref($this) || $this;
    my $self = {};
    bless $self, $class;
    return $self;
}


=head2 fetchIds($id)

Fetches the enterprise document with the id $id from the RPC::OGo
database. Returns the SOAP::Lite->result from this call.

=cut
sub fetchIds {
    my ($self,$qualifier) = @_;
    $qualifier = "number like '*'" unless $qualifier;

    return $self->_call('fetchIds',{ qualifier => $qualifier});
}


=head2 delete($id)

Deletes the enterprise entry with the number $number (from
RPC::OGo::Document::Enterprise->number()) from the RPC::OGo
database. Returns the SOAP::Lite->result from this call.  Returns the
current object.

=cut
sub delete {
    my ($self,$number) = @_;
    $self->_call('delete',$number);
    return $self;
}


=head2 get($id)

Fetches the enterprise document with the id $id from the RPC::OGo
database. Returns the SOAP::Lite->result from this call.

=cut
sub get {
    my ($self,$id) = @_;

    return $self->_call('get',$id);
}


### EOP ###
1;
__END__

=head1 AUTHOR

Martin Werthmoeller <lt>mw@werthmoeller.de<gt>

=head1 SEE ALSO

L<perl>, L<RPC::OGo::Document>.

=cut

